@@ -9,17 +9,18 @@ class DecayFunction(Enum):
 
 class TimedDecay:
     def __init__(self,
-                 time_until_zero_ms: float,
+                 time_ms: float,
                  init_value: float = None,
+                 start_perf: float = None,
                  decay_function: DecayFunction = None):
-        self.time_until_zero_ms = time_until_zero_ms
-        self.start_perf = None
+        self.time_ms = time_ms
+        self.start_perf = start_perf
         self.init_value = init_value if init_value else 1
         self.decay_function = decay_function if decay_function else DecayFunction.UNIFORM
 
-        self._r = 1 / self.time_until_zero_ms * 1000
+        self._r = 1 / self.time_ms * 1000
 
-    def set_timer(self, at_time):
+    def set_start(self, at_time):
         self.start_perf = at_time
 
     def check(self, at_time) -> Optional[float]:
@@ -35,23 +36,26 @@ class TimedDecay:
         return val
 
     @property
-    def end_time(self):
+    def EndTime(self):
         if not self.start_perf:
             return None
 
-        return self.start_perf + self.time_until_zero_ms / 1000
+        return self.start_perf + self.time_ms
 
-    def progress_time(self, at_time):
+    def progress_at_time(self, at_time):
         if not self.start_perf:
             return None
 
-        return min((at_time - self.start_perf) / (self.end_time - self.start_perf), 1)
+        return min((at_time - self.start_perf) / (self.EndTime - self.start_perf), 1)
 
     def progress_val(self, at_time):
         if not self.start_perf:
             return None
 
-        return min((self.init_value - self.check(at_time)) / (self.init_value))
+        return min((self.init_value - self.check(at_time)) / (self.init_value), 1)
+
+    def time_until_zero_ms(self, at_time):
+        return self.time_ms * (1 - self.progress_at_time(at_time))
 
 
 class Timer:
@@ -70,7 +74,7 @@ class Timer:
             self._time_ms = time_ms
 
         self._decayer = TimedDecay(self._time_ms)
-        self._decayer.set_timer(time.perf_counter())
+        self._decayer.set_start(time.perf_counter())
 
     @property
     def finished(self) -> bool:
@@ -92,7 +96,7 @@ class Timer:
         if not self._decayer:
             return None
 
-        return self._decayer.progress_time(time.perf_counter())
+        return self._decayer.progress_at_time(time.perf_counter())
 
     @property
     def time_ms(self):
